==> haskell-microlens-ghc-0.4.14.3-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-ghc
version:              0.4.14.3
visibility:           public
id:                   microlens-ghc-0.4.14.3-2BmMTTjNdLG3FnUhKIimXA
key:                  microlens-ghc-0.4.14.3-2BmMTTjNdLG3FnUhKIimXA
license:              BSD-3-Clause
maintainer:           Steven Fontanella <steven.fontanella@gmail.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/stevenfontanella/microlens
synopsis:             microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).

    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/stevenfontanella/microlens#readme on Github>.

category:             Data, Lenses
abi:                  a7a075d476392849fd05782ff3e287da
exposed:              True
exposed-modules:      Lens.Micro.GHC Lens.Micro.GHC.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/microlens-ghc-0.4.14.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/microlens-ghc-0.4.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-ghc
hs-libraries:         HSmicrolens-ghc-0.4.14.3-2BmMTTjNdLG3FnUhKIimXA
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock

haddock-html:         /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-ghc-0.4.14.3-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microlens-ghc
version:              0.4.14.3
visibility:           public
id:                   microlens-ghc-0.4.14.3-Heca6Vy1EAEBeqiy3itZhT
key:                  microlens-ghc-0.4.14.3-Heca6Vy1EAEBeqiy3itZhT
license:              BSD-3-Clause
maintainer:           Steven Fontanella <steven.fontanella@gmail.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/stevenfontanella/microlens
synopsis:             microlens + array, bytestring, containers, transformers
description:
    Use this package instead of <http://hackage.haskell.org/package/microlens microlens> if you don'\''t mind depending on all dependencies here – @Lens.Micro.GHC@ reexports everything from @Lens.Micro@ and additionally provides orphan instances of microlens classes for packages coming with GHC (<http://hackage.haskell.org/package/array array>, <http://hackage.haskell.org/package/bytestring bytestring>, <http://hackage.haskell.org/package/containers containers>, <http://hackage.haskell.org/package/transfromers transformers>).

    The minor and major versions of microlens-ghc are incremented whenever the minor and major versions of microlens are incremented, so you can depend on the exact version of microlens-ghc without specifying the version of microlens you need.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/stevenfontanella/microlens#readme on Github>.

category:             Data, Lenses
abi:                  12a2e1f0cd4dfb9c66cf37a2fe0ede5a
exposed:              True
exposed-modules:      Lens.Micro.GHC Lens.Micro.GHC.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/microlens-ghc-0.4.14.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microlens-ghc-0.4.14.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microlens-ghc-0.4.14.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-ghc
hs-libraries:         HSmicrolens-ghc-0.4.14.3-Heca6Vy1EAEBeqiy3itZhT
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-microlens-ghc/html/microlens-ghc.haddock

haddock-html:         /usr/share/doc/haskell-microlens-ghc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
